@@ -22,8 +22,8 @@
 
 #include "karecurrence.h"
 
-#include <kcalcore/recurrence.h>
-#include <kcalcore/icalformat.h>
+#include <kcalendarcore/recurrence.h>
+#include <kcalendarcore/icalformat.h>
 
 #include "kalarmcal_debug.h"
 
@@ -31,7 +31,7 @@
 #include <QDate>
 #include <QLocale>
 
-using namespace KCalCore;
+using namespace KCalendarCore;
 namespace KAlarmCal
 {
 
@@ -115,7 +115,7 @@ KARecurrence::KARecurrence()
     : d(new Private)
 { }
 
-KARecurrence::KARecurrence(const KCalCore::Recurrence &r)
+KARecurrence::KARecurrence(const KCalendarCore::Recurrence &r)
     : d(new Private(r))
 {
     fix();
@@ -216,7 +216,7 @@ bool KARecurrence::Private::set(Type recurType, int freq, int count, int f29, co
 * Initialise a KARecurrence from recurrence parameters.
 * Reply = true if successful.
 */
-bool KARecurrence::init(KCalCore::RecurrenceRule::PeriodType t, int freq, int count,
+bool KARecurrence::init(KCalendarCore::RecurrenceRule::PeriodType t, int freq, int count,
                         const KADateTime &start, const KADateTime &end)
 {
     return d->init(t, freq, count, -1, start, end);
@@ -485,7 +485,7 @@ void KARecurrence::Private::fix()
 * Initialise a KCal::Recurrence to be the same as this instance.
 * Additional recurrence rules are created as necessary if it recurs on Feb 29th.
 */
-void KARecurrence::writeRecurrence(KCalCore::Recurrence &recur) const
+void KARecurrence::writeRecurrence(KCalendarCore::Recurrence &recur) const
 {
     d->writeRecurrence(this, recur);
 }
@@ -1268,7 +1268,7 @@ KARecurrence::Type KARecurrence::type() const
 /******************************************************************************
 * Return the recurrence rule type.
 */
-KARecurrence::Type KARecurrence::type(const KCalCore::RecurrenceRule *rrule)
+KARecurrence::Type KARecurrence::type(const KCalendarCore::RecurrenceRule *rrule)
 {
     switch (Recurrence::recurrenceType(rrule)) {
     case Recurrence::rMinutely:     return MINUTELY;
